summaryrefslogtreecommitdiff
path: root/cesar/cp2/cco/action/action.h
diff options
context:
space:
mode:
authorchertier2008-04-22 16:19:13 +0000
committerchertier2008-04-22 16:19:13 +0000
commit0279ede89f4a2e1a815f817946cb2db2ab340370 (patch)
tree03b23dacc3e188d45ac5525aab4123151b6d29a3 /cesar/cp2/cco/action/action.h
parentcdc273b6c990dca15d9736109d6315d4acc20eee (diff)
update
git-svn-id: svn+ssh://pessac/svn/cesar/trunk@1874 017c9cb6-072f-447c-8318-d5b54f68fe89
Diffstat (limited to 'cesar/cp2/cco/action/action.h')
-rw-r--r--cesar/cp2/cco/action/action.h27
1 files changed, 19 insertions, 8 deletions
diff --git a/cesar/cp2/cco/action/action.h b/cesar/cp2/cco/action/action.h
index ebfb28c7bb..74ff4e3a28 100644
--- a/cesar/cp2/cco/action/action.h
+++ b/cesar/cp2/cco/action/action.h
@@ -56,13 +56,23 @@ BEGIN_DECLS
/**
* initialisation of CCo action module.
*
* \param ctx control plane context
*/
-void
+cco_action_t *
cp_cco_action_init(cp_t *ctx);
/**
- * initialisation of "SNID in use" flags.
+ * uninitialisation of CCo action module.
+ *
+ * \param ctx control plane context
+ */
+void
+cp_cco_action_uninit(cp_t *ctx);
+
+/**
+ * initialisation (reset) of "SNID in use" flags.
*
* \param ctx control plane context
*/
@@ -73,6 +83,7 @@ cp_cco_action_reset_snid_flags(cp_t *ctx);
* check against SNID conflict.
*
* \param ctx control plane context
+ * \param snid SNID in incoming beacon or MME message
*
* \return true if SNID conflict, else false
*
@@ -178,7 +189,7 @@ bool
cp_cco_action_remove_tei_lease(cp_t *ctx, tei_t *p_tei);
/**
- * check and release elapsed TEI leases
+ * check and release elapsed TEI leases.
*
* \param ctx control plane context
*
@@ -266,10 +277,10 @@ void cp_cco_action_manage_rx_beacon(cp_t *ctx, cp_beacon_t *beacon);
* 2) else if CC_ASSOC.REQ ReqType field value is "renew", call cp_cco_action_renew_tei_lease()
* to update (renew) the TEI lease
* (lease = 15 minutes if STA still not authenticated, 48 Hours if STA is authenticated ? Table 11-212)
- * 2) update CCo dataset (list of TEI lease, and may be TEI / MAC address list ?)
- * 3) prepare CM_ASSOC.CNF MME to be sent back to the STA that sent the assoc request
- * 4) send CM_ASSOC.CNF MME back to the STA that sent the assoc request
- * 5) if the CM_ASSOC.CNF was a positive confirmation, put a STA_JOINED event in the FSM
+ * 3) update CCo dataset (list of TEI lease, and may be TEI / MAC address list ?)
+ * 4) prepare CM_ASSOC.CNF MME to be sent back to the STA that sent the assoc request
+ * 5) send CM_ASSOC.CNF MME back to the STA that sent the assoc request
+ * 6) if the CM_ASSOC.CNF was a positive confirmation, put a STA_JOINED event in the FSM
*/
void cp_cco_action_manage_sta_assoc(cp_t *ctx, cp_mme_rx_t assoc_req);
@@ -56,13 +56,23 @@ BEGIN_DECLS
* initialisation of CCo action module.
*
- * \param ctx control plane context
+ * \param ctx control plane context
+ *
+ * \return pointer to cco_action context
*/